import flask

from api.routes import *
from api.user import user_info_list_db_to_json, get_user_settings, update_user_settings

_SQL_GET_USERS = PreparedStatement("""
    SELECT * FROM "users"
""")


@api_route("/users", ["GET"], allow_while_readonly=True)
@api_moderator_route()
def api_route_users():
    user_list_db = db_pool.execute_read_statement_in_transaction(_SQL_GET_USERS)
    return {
        "users": user_info_list_db_to_json(user_list_db)
    }


@api_route("/user/me/settings", ["GET", "PATCH"], allow_while_readonly=True)
@api_moderator_route()
def api_route_user_me_settings():
    if flask.request.method == "GET":
        settings = get_user_settings(get_user_id())
        if settings is None:
            raise RuntimeError("No db user for moderator")  # pragma: no cover
        return settings
    if api.live_config.is_readonly():
        raise ApiClientException(ERROR_SITE_IS_READONLY)
    check_csrf_token()
    updates = get_client_json(flask.request).get_object("updates")
    update_user_settings(get_user_id(), updates)
    return {}
